@@ -55,9 +55,6 @@
 #elif HAVE_SYS_MOUNT_H
 #include <sys/mount.h>
 #endif
-#if HAVE_SYS_STATFS_H
-#include <sys/statfs.h>
-#endif
 
 #define KILOBYTE_FACTOR 1024.0
 #define MEGABYTE_FACTOR (1024.0 * 1024.0)
@@ -765,7 +762,7 @@ gnome_vfs_get_uri_from_local_path (const char *local_full_path)
  * @size:
  * 
  * Stores in @size the amount of free space on a volume.
- * This only works for URIs with the file: scheme.
+ * This only works for local file systems with the file: scheme.
  *
  * Returns: GNOME_VFS_OK on success, otherwise an error code
  */
@@ -803,44 +800,15 @@ gnome_vfs_get_volume_free_space (const GnomeVFSURI *vfs_uri,
 #if HAVE_STATVFS
 	statfs_result = statvfs (unescaped_path, &statfs_buffer);
 #else
-#if STATFS_ARGS == 2
 	statfs_result = statfs (unescaped_path, &statfs_buffer);   
-#elif STATFS_ARGS == 4
-	statfs_result = statfs (unescaped_path, &statfs_buffer,
-				sizeof (statfs_buffer), 0);
-#endif
 #endif  
 
+	g_free (unescaped_path);
+
 	if (statfs_result != 0) {
-		g_free (unescaped_path);
 		return gnome_vfs_result_from_errno ();
 	}
-
-/* CF: I assume ncpfs is linux specific, if you are on a non-linux platform
- * where ncpfs is available, please file a bug about it on bugzilla.gnome.org
- * (2004-03-08)
- */
-#if defined(__linux__)
-	/* ncpfs does not know the amount of available and free space */
-	if (statfs_buffer.f_bavail == 0 && statfs_buffer.f_bfree == 0) {
-		/* statvfs does not return f_type on ncpfs, we try again
-		 * with statfs.
-		 */
-		struct statfs statfs_buffer2;
-		statfs_result = statfs (unescaped_path, &statfs_buffer2);
-		g_free (unescaped_path);
-
-		if (statfs_result != 0) {
-			return gnome_vfs_result_from_errno ();
-		}
-		
-		/* linux/ncp_fs.h: NCP_SUPER_MAGIC == 0x564c */
-		if (statfs_buffer2.f_type == 0x564c) {
-			return GNOME_VFS_ERROR_NOT_SUPPORTED;
-		}
-	}
-#endif
-
+	
 	block_size = statfs_buffer.f_bsize; 
 	free_blocks = statfs_buffer.f_bavail;
 
