@@ -2207,13 +2207,6 @@ make_propfind_request (HttpFileHandle **handle_return,
 		DEBUG_HTTP (("HTTP server returned an invalid PROPFIND response: %d", (*handle_return)->server_status));
 		result = GNOME_VFS_ERROR_NOT_SUPPORTED;
 	}
-	/* Some servers (download.microsoft.com) will just close
-	 * the connection (EOF) without returning any HTTP status.
-	 */
-	if (result == GNOME_VFS_ERROR_EOF) {
-		DEBUG_HTTP (("HTTP server returned an empty PROPFIND response"));
-		result = GNOME_VFS_ERROR_NOT_SUPPORTED;
-	}
 	
 	if (result == GNOME_VFS_OK) {
 		do {
@@ -2512,7 +2505,6 @@ do_get_file_info (GnomeVFSMethod *method,
 					gnome_vfs_file_info_copy (file_info, handle->file_info);
 					http_cache_add_uri (uri, handle->file_info, FALSE);
 					http_handle_close (handle, context);
-					handle = NULL;
 				}
 
 				/* If we get a redirect, we should be
